Scripts to reproduce bugs
=========================

We can put in this repository `Minimal, Complete, and Verifiable examples
<https://stackoverflow.com/help/mcve>`_.

- Choose an understandable name for the script.

- Try to make the execution to get the bug as short as possible.

- Try to study when the bug happens and when it does not happen (for example,
  does it happen for different solvers).

- Explain in the docstring of the script what is the problem (with the
  traceback you obtain) and how to reproduce it.
